@@ -1,5 +1,5 @@
 import re
-from typing import List, Union, Iterable, Any, Dict
+from typing import List, Union, Iterable, Any, Dict, Literal, Tuple
 
 from .config import lang
 from .core import BasePattern, PatternModel
@@ -44,7 +44,7 @@ class UnionArg(BasePattern):
         if text not in self.for_equal:
             for pat in self.for_validate:
                 if (res := pat.validate(text)).success:
-                    return res
+                    return res.value
             raise MatchFailed(lang.content_error.format(target=text))
         return text
 
@@ -53,16 +53,42 @@ class UnionArg(BasePattern):
             "|".join(repr(a) for a in (*self.for_validate, *self.for_equal))
         )
 
+    def prefixed(self) -> "UnionArg":
+        from .main import type_parser
+
+        return UnionArg(
+            [pat.prefixed() for pat in self.for_validate]
+            + [
+                type_parser(eq).prefixed() if isinstance(eq, str) else eq
+                for eq in self.for_equal
+            ],
+            self.anti,
+        )
+
+    def suffixed(self) -> "UnionArg":
+        from .main import type_parser
+
+        return UnionArg(
+            [pat.suffixed() for pat in self.for_validate]
+            + [
+                type_parser(eq).suffixed() if isinstance(eq, str) else eq
+                for eq in self.for_equal
+            ],
+            self.anti,
+        )
+
 
 class SequenceArg(BasePattern):
     """匹配列表或者元组或者集合"""
 
     form: str
     arg_value: BasePattern
+    _mode: Literal["pre", "suf", "all"]
 
     def __init__(self, base: BasePattern, form: str = "list"):
         self.form = form
         self.arg_value = base
+        self._mode = "all"
         if form == "list":
             super().__init__(
                 r"\[(.+?)\]", PatternModel.REGEX_MATCH, list, alias=f"list[{base}]"
@@ -80,27 +106,54 @@ class SequenceArg(BasePattern):
 
     def match(self, text: Union[str, Any]):
         _res = super().match(text)
-        result = []
-        for s in re.split(r"\s*,\s*", _res) if isinstance(_res, str) else _res:
+        _max = 0
+        success: List[Tuple[int, Any]] = []
+        fail: List[Tuple[int, MatchFailed]] = []
+        for _max, s in enumerate(
+            re.split(r"\s*,\s*", _res) if isinstance(_res, str) else _res
+        ):
             try:
-                result.append(self.arg_value.match(s))
-            except MatchFailed as e:
-                raise MatchFailed(f"{s} is not matched with {self.arg_value}") from e
-        return self.origin(result)
+                success.append((_max, self.arg_value.match(s)))
+            except MatchFailed:
+                fail.append(
+                    (_max, MatchFailed(f"{s} is not matched with {self.arg_value}"))
+                )
+
+        if (
+            (self._mode == "all" and fail)
+            or (self._mode == "pre" and fail and fail[0][0] == 0)
+            or (self._mode == "suf" and fail and fail[-1][0] == _max)
+        ):
+            raise fail[0][1]
+        if self._mode == "pre" and fail:
+            return self.origin(i[1] for i in success if i[0] < fail[0][0])
+        if self._mode == "suf" and fail:
+            return self.origin(i[1] for i in success if i[0] > fail[-1][0])
+        return self.origin(i[1] for i in success)
 
     def __repr__(self):
         return f"{self.form}[{self.arg_value}]"
 
+    def prefixed(self):
+        self._mode = "pre"
+        return super(SequenceArg, self).prefixed()
+
+    def suffixed(self):
+        self._mode = "suf"
+        return super(SequenceArg, self).suffixed()
+
 
 class MappingArg(BasePattern):
     """匹配字典或者映射表"""
 
     arg_key: BasePattern
     arg_value: BasePattern
+    _mode: Literal["pre", "suf", "all"]
 
     def __init__(self, arg_key: BasePattern, arg_value: BasePattern):
         self.arg_key = arg_key
         self.arg_value = arg_value
+        self._mode = "all"
         super().__init__(
             r"\{(.+?)\}",
             PatternModel.REGEX_MATCH,
@@ -110,7 +163,9 @@ class MappingArg(BasePattern):
 
     def match(self, text: Union[str, Any]):
         _res = super().match(text)
-        result = {}
+        success: List[Tuple[int, Any, Any]] = []
+        fail: List[Tuple[int, MatchFailed]] = []
+        _max = 0
 
         def _generator_items(res: Union[str, Dict]):
             if isinstance(res, dict):
@@ -119,21 +174,34 @@ class MappingArg(BasePattern):
             for m in re.split(r"\s*,\s*", res):
                 yield re.split(r"\s*[:=]\s*", m)
 
-        for k, v in _generator_items(_res):
+        for _max, item in enumerate(_generator_items(_res)):
+            k, v = item
             try:
-                real_key = self.arg_key.match(k)
-            except MatchFailed as e:
-                raise MatchFailed(f"{k} is not matched with {self.arg_key}") from e
-            try:
-                arg_find = self.arg_value.match(v)
-            except MatchFailed as e:
-                raise MatchFailed(f"{v} is not matched with {self.arg_value}") from e
-            result[real_key] = arg_find
-
-        return result
+                success.append((_max, self.arg_key.match(k), self.arg_value.match(v)))
+            except MatchFailed:
+                fail.append((_max, MatchFailed(f"{k}: {v} is not matched with {self.arg_key}: {self.arg_value}")))
+        if (
+            (self._mode == "all" and fail)
+            or (self._mode == "pre" and fail and fail[0][0] == 0)
+            or (self._mode == "suf" and fail and fail[-1][0] == _max)
+        ):
+            raise fail[0][1]
+        if self._mode == "pre" and fail:
+            return {i[1]: i[2] for i in success if i[0] < fail[0][0]}
+        if self._mode == "suf" and fail:
+            return {i[1]: i[2] for i in success if i[0] > fail[-1][0]}
+        return {i[1]: i[2] for i in success}
 
     def __repr__(self):
         return f"dict[{self.arg_key.origin.__name__}, {self.arg_value}]"
 
+    def prefixed(self):
+        self._mode = "pre"
+        return super(MappingArg, self).prefixed()
+
+    def suffixed(self):
+        self._mode = "suf"
+        return super(MappingArg, self).suffixed()
+
 
 __all__ = ["UnionArg", "SequenceArg", "MappingArg"]
